@@ -5,7 +5,8 @@ sub new
 {
    ++$n;
    my $type = shift;
-   bless { @_ }, $type;
+   my $self = bless { @_ }, $type;
+   return $self;
 }
 
 sub DESTROY
@@ -64,4 +65,4 @@ sub same
    '';
 }
 
-1;
\ No newline at end of file
+1;
